<?php
/**
 * functions and definitions
 *
 */
 
if ( ! isset( $content_width ) )
	$content_width = 654; /* pixels */

if ( ! function_exists( 'decemberable_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 */
function decemberable_setup() {

	/**
	 * Custom template tags for this theme.
	 */
	require( get_template_directory() . '/inc/template-tags.php' );
	
	/**
	 * Custom functions that act independently of the theme templates
	 */
	require( get_template_directory(). '/inc/tweaks.php' );
	
	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme, use a find and replace
	 * to change 'decemberable' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'decemberable', get_template_directory() . '/languages' );
	
	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links');
	
	/**
	 * Enable support for the Aside Post Format
	 */
	add_theme_support( 'post-formats', array( 'aside' ) );
	
	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'decemberable' ),
	) );
	
}
endif; // decemberable_setup
add_action( 'after_setup_theme', 'decemberable_setup');

/**
 * Register widgetized area and update sidebar with default widgets
 *
 */
function decemberable_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Primary Widget Area', 'decemberable' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
	register_sidebar ( array(
		'name' => __( 'Secondary Widget Area', 'decemberable' ),
		'id' => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1',
	) );
}
add_action( 'widgets_init', 'decemberable_widgets_init' );

/**
 * Enqueue scripts and style
 */
function decemberable_scripts() {
	wp_enqueue_style( 'style', get_stylesheet_uri() );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
		
	wp_enqueue_script( 'navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	
	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
}
add_action( 'wp_enqueue_scripts', 'decemberable_scripts');

/**
 * Setup the WordPress core custom background feature.
 *
 * Use add_theme_support to register support for WordPress 3.4+
 * as well as provide backward compatibility for previous versions.
 * Use feature detection of wp_get_theme() which was introduced
 * in WordPress 3.4.
 *
 * Hooks into the after_setup_theme action.
 *
 */
function decemberable_register_custom_background() {
	$args = array(
		'default-color' => 'f1f1f1',
	);
		
	$args = apply_filters( 'decemberable_custom_background_args', $args );
		
	if ( function_exists( 'wp_get_theme' ) ) {
		add_theme_support( 'custom-background', $args );
	} else {
		define( 'BACKGROUND_COLOR', $args['default-color'] );
		define( 'BACKGROUND_IMAGE', $args['default-image'] );
		add_theme_support( 'custom-background' );
	}
}
add_action( 'after_setup_theme', 'decemberable_register_custom_background' );

/**
 * Implement the Custom Header feature
 */
require( get_template_directory() . '/inc/custom-header.php' );

/**
 * Enabling support for post thumbnails
 */
add_theme_support( 'post-thumbnails' );

add_image_size( 'mycustomsize', 220, 170, true);

/**
 * Add editor style
 * Allows theme developers to link a custom stylesheet file to the TinyMCE visual editor
 */
function my_theme_add_editor_styles() {
	add_editor_style( 'custom-editor-style.css' );
}
add_action( 'init', 'my_theme_add_editor_styles' );